@@ -9,12 +9,17 @@ To use this module, you have to define at least a channel name.
 
 
 import redis
+import time
 from logbook import Logger
-import ConfigParser
+try:
+    import configparser
+except ImportError:
+    import ConfigParser as configparser
 from logbook import NestedSetup
 from logbook import NullHandler
 from logbook import TimedRotatingFileHandler
 from logbook import MailHandler
+from logbook import SyslogHandler
 import os
 
 # use a TCP Socket by default
@@ -36,7 +41,7 @@ smtp_port = 0
 src_server = None
 
 
-def setup(name, path='log', enable_debug=False):
+def setup(name, path='log', enable_debug=False, syslog=False):
     """
     Prepare a NestedSetup.
 
@@ -73,6 +78,13 @@ def setup(name, path='log', enable_debug=False):
         debug = path_tmpl.format(name=name, level='debug')
         setup.insert(1, TimedRotatingFileHandler(debug, level='DEBUG',
                      encoding='utf-8', date_format='%Y-%m-%d'))
+
+    if syslog:
+        #address=
+        setup.append(SyslogHandler(warn, level='WARNING'))
+        setup.append(SyslogHandler(err, level='ERROR'))
+        setup.append(SyslogHandler(crit, level='CRITICAL'))
+
     if src_server is not None and smtp_server is not None \
             and smtp_port != 0 and len(dest_mails) != 0:
         mail_tmpl = '{name}_error@{src}'
@@ -97,7 +109,7 @@ def mail_setup(path):
     global smtp_server
     global smtp_port
     global src_server
-    config = ConfigParser.RawConfigParser()
+    config = configparser.RawConfigParser()
     config.readfp(path)
     dest_mails = config.get('mail', 'dest_mail').split(',')
     smtp_server = config.get('mail', 'smtp_server')
@@ -105,7 +117,7 @@ def mail_setup(path):
     src_server = config.get('mail', 'src_server')
 
 
-def run(log_name, path, debug=False, mail=None):
+def run(log_name, path, debug=False, mail=None, syslog=False, timeout=0):
     """
     Run a subscriber and pass the messages to the logbook setup.
     Stays alive as long as the pubsub instance listen to something.
@@ -114,6 +126,7 @@ def run(log_name, path, debug=False, mail=None):
     :param path: the path where the log files will be written
     :param debug: True if you want to save the debug messages too
     :param mail: Path to the config file for the mails
+    :param syslog: enable syslog
 
     """
     global pubsub
@@ -126,6 +139,9 @@ def run(log_name, path, debug=False, mail=None):
     pubsub = r.pubsub()
     pubsub.psubscribe(channel + '.*')
 
+    if timeout != 0:
+        deadline = time.time() + timeout
+
     logger = Logger(channel)
     if mail is not None:
         mail_setup(mail)
@@ -133,16 +149,22 @@ def run(log_name, path, debug=False, mail=None):
         raise Exception("The path you want to use to save the file is invalid (not a directory).")
     if not os.path.exists(path):
         os.mkdir(path)
-    with setup(channel, path, debug):
-        for msg in pubsub.listen():
-            if msg['type'] == 'pmessage':
-                level = msg['channel'].split('.')[1]
-                message = msg['data']
-                try:
-                    message = message.decode('utf-8')
-                except:
-                    pass
-                logger.log(level, message)
+    with setup(channel, path, debug, syslog):
+        while True:
+            msg = pubsub.get_message()
+            if msg:
+                if msg['type'] == 'pmessage':
+                    level = msg['channel'].decode('utf-8').split('.')[1]
+                    message = msg['data']
+                    try:
+                        message = message.decode('utf-8')
+                    except:
+                        pass
+                    logger.log(level, message)
+            time.sleep(0.01)
+            if timeout > 0:
+                if time.time() >= deadline:
+                    break
 
 
 def stop():
